# Plotting

::::{grid} 3

:::{grid-item-card} Line plot
:link: line-plot.ipynb
:img-bottom: ../_static/plotting/line-plot.png

:::

:::{grid-item-card} Image plot
:link: image-plot.ipynb
:img-bottom: ../_static/plotting/image-plot.png

:::

::::{grid-item-card} Scatter plot
:link: scatter-plot.ipynb
:img-bottom: ../_static/plotting/scatter-plot.png

:::

::::

::::{grid} 3

:::{grid-item-card} Slicer plot
:link: slicer-plot.ipynb
:img-bottom: ../_static/plotting/slicer-plot.png

:::

:::{grid-item-card} Inspector plot
:link: inspector-plot.ipynb
:img-bottom: ../_static/plotting/inspector-plot.png

:::

:::{grid-item-card} Super-plot
:link: super-plot.ipynb
:img-bottom: ../_static/plotting/super-plot.png

:::

::::

::::{grid} 3

:::{grid-item-card} Scatter 3D plot
:link: scatter3d-plot.ipynb
:img-bottom: ../_static/plotting/scatter3d-plot.png

:::

:::{grid-item-card} Mesh 3D plot
:link: mesh3d-plot.ipynb
:img-bottom: ../_static/plotting/mesh3d-plot.png

:::

::::

```{toctree}
---
hidden:
---

line-plot
image-plot
slicer-plot
inspector-plot
super-plot
scatter-plot
scatter3d-plot
mesh3d-plot
```
